# -*- coding: utf-8 -*-

from .vals import logger


def safe_call(func, *args, **kwargs):
    """
    安全调用
    """
    try:
        return func(*args, **kwargs)
    except Exception, e:
        logger.exception('func raise exception. func: %s', func.__name__)
